timeseries.Signal.iter_features — GDA Toolbox v1.0 Manual

- GDA Toolbox v1.0 Manual
- Time-Series Data
- timeseries.Signal

- index
- modules
- next
- previous

# timeseries.Signal.iter_features

`Signal.` `iter_features`(min_pers=0, depth_first=False)

  walk the feature tree.

#### Previous topic

timeseries.Signal.interval_height

#### Next topic

timeseries.Signal.iter_intervals

- © Copyright 2015-2017, Geometric Data Analytics, Inc.
- Last updated on Jan 07, 2019.
- Created using Sphinx 1.8.2.